@@ -1,7 +1,6 @@
 package Net::RDAP::Object;
 use base qw(Net::RDAP::Base);
 use strict;
-use warnings;
 
 =pod
 
@@ -20,62 +19,11 @@ L<Net::RDAP::Object> represents such objects, whether top-level or
 embedded. It inherits from L<Net::RDAP::Base> so has all the methods
 available to that module.
 
-=cut
+Other methods include:
 
-#
-# Constructor method. $args is a hashref, $url is the URL this
-# object was loaded from
-#
-sub new {
-    my ($package, $args, $document_url, $parent) = @_;
+	$class = $object->class;
 
-    return $package->SUPER::new($args, $document_url, $parent);
-}
-
-=pod
-
-=head1 METHODS
-
-=head2 RDAP Conformance
-
-    @conformance = $response->conformance;
-
-Returns an array of strings, each providing a hint as to the
-specifications used (by the server) in the construction of the response.
-
-This method will return C<undef> unless called on the top-most object
-in a response.
-
-=cut
-
-sub conformance {
-    my $self = shift;
-    return @{$self->{'rdapConformance'} || []};
-}
-
-=pod
-
-=head2 Notices
-
-    @notices = $response->notices;
-
-Returns a (potentially empty) array of L<Net::RDAP::Notice> objects.
-
-The array will always be empty unless called on the top-most object
-in a response.
-
-=cut
-
-sub notices { $_[0]->objects('Net::RDAP::Notice', $_[0]->{'notices'}) }
-
-=pod
-
-=head2 Object Class
-
-    $class = $object->class;
-
-Returns a string containing the "class name" of this object (i.e., one
-of: C<ip network>, C<entity>, C<nameserver>, C<autnum> or C<domain>).
+Returns a string containing the class name of this object.
 
 =cut
 
@@ -83,9 +31,7 @@ sub class { $_[0]->{'objectClassName'} }
 
 =pod
 
-=head2 Handle
-
-    $handle = $object->handle;
+	$handle = $object->handle;
 
 Returns a string containing the "handle" of the object.
 
@@ -95,9 +41,7 @@ sub handle { $_[0]->{'handle'} }
 
 =pod
 
-=head2 Status
-
-    @status = $object->status;
+	@status = $object->status;
 
 Returns a (potentially empty) array of state identifiers. The possible
 values are defined by bn IANA registry; see:
@@ -114,9 +58,7 @@ sub status { $_[0]->{'status'} ? @{$_[0]->{'status'}} : () }
 
 =pod
 
-=head2 Remarks
-
-    @remarks = $object->remarks;
+	@remarks = $object->remarks;
 
 Returns a (potentially empty) array of L<Net::RDAP::Remark> objects.
 
@@ -126,9 +68,7 @@ sub remarks { $_[0]->objects('Net::RDAP::Remark', $_[0]->{'remarks'}) }
 
 =pod
 
-=head2 Events
-
-    @events = $object->events;
+	@events = $object->events;
 
 Returns a (potentially empty) array of L<Net::RDAP::Event> objects.
 
@@ -138,9 +78,7 @@ sub events { $_[0]->objects('Net::RDAP::Event', $_[0]->{'events'}) }
 
 =pod
 
-=head2 Port-43 Whois Server
-
-    $port43 = $object->port43;
+	$port43 = $object->port43;
 
 Returns a L<Net::DNS::Domain> object containing the name of the
 legacy port-43 whois server for this object.
@@ -151,9 +89,7 @@ sub port43 { $_[0]->{'port43'} }
 
 =pod
 
-=head2 Public IDs
-
-    @ids = $object->ids;
+	@ids = $object->ids;
 
 Returns a (potentially empty) array of L<Net::RDAP::ID> objects.
 
@@ -163,35 +99,19 @@ sub ids { $_[0]->objects('Net::RDAP::ID', $_[0]->{'publicIds'}) }
 
 =pod
 
-=head2 Entities
+	@entities = $object->entities;
 
-    @entities = $object->entities;
-
-Returns a (potentially empty) array of L<Net::RDAP::Object::Entity> objects.
+Returns a (potentially empty) array of L<Net::RDAP::Entity> objects.
 
 =cut
 
-sub entities { $_[0]->objects('Net::RDAP::Object::Entity', $_[0]->{'entities'}) }
-
-=pod
-
-=head2 Redactions
-
-    @redactions = $object->redactions;
-
-If the server supports L<RFC 9537|https://www.rfc-editor.org/rfc/rfc9537.html>,
-then this method will return an array of L<Net::RDAP::Redaction> objects
-corresponding to the fields listed in the C<redacted> property of the object.
-
-=cut
-
-sub redactions { $_[0]->objects('Net::RDAP::Redaction', $_[0]->{'redacted'}) }
+sub entities { $_[0]->objects('Net::RDAP::Entity', $_[0]->{'entities'}) }
 
 =pod
 
 =head1 COPYRIGHT
 
-Copyright 2018-2023 CentralNic Ltd, 2024 Gavin Brown. All rights reserved.
+Copyright 2018 CentralNic Ltd. All rights reserved.
 
 =head1 LICENSE
 
@@ -213,4 +133,4 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
 
-1;
+1;
\ No newline at end of file
